import logging
import sys
import time

from take_a_break.configuration import CONFIG
from take_a_break.gui.tbmain import TBMain

logging.basicConfig(level=logging.DEBUG,
                    format='(%(threadName)-9s) %(message)s', )

if __name__ == '__main__':
    try:
        logging.info('Application started!')
        while True:
            TBMain().show()
            time.sleep(CONFIG.remind_me_after_this_period())
    except KeyboardInterrupt:
        logging.info("Bye, bye...")
        sys.exit()



__version__ = "0.2"

import os

import requests
from PIL import Image


def get_resources(filename):
    """
    :param filename: the name of the filname
    :return: the filename path from resources folder
    """
    dirname = os.path.join(os.path.dirname(__file__), 'resources')
    fullname = os.path.join(dirname, filename)
    return fullname


def temp_file(filename):
    """
    :param filename:
    :return: the filename path from the TEMP folder
    """
    pass


def get_random_joke():
    response = requests.get("http://api.icndb.com/jokes/random")
    if response.status_code == requests.codes.ok:
        joke = response.json()["value"]["joke"]
        print(joke)
        joke = joke.replace("&quot;", "\"")
        return joke
    else:
        return "Take a brake! You need it!"


def jpeg_to_png(image):
    png_image = "{}.png".format(os.path.splitext(image)[0])
    Image.open(image).save(png_image)
    os.remove(image)
    return png_image



import shutil

import requests

from take_a_break import get_resources, jpeg_to_png
from take_a_break.providers import Provider


class UnsplashAPI(Provider):
    def __init__(self, endpoint="https://source.unsplash.com/random/1280x1080"):
        self.endpoint = endpoint

    def get_random_image(self):
        response = requests.get(self.endpoint, stream=True)
        if response.status_code == 200:
            response.raw.decode_content = True
            with open(get_resources("random.jpg"), 'wb') as f:
                shutil.copyfileobj(response.raw, f)
            return jpeg_to_png(get_resources("random.jpg"))



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

files = ["resources/*"]

setuptools.setup(
    name="take-a-break",
    author="Paul Brodner",
    author_email="paulbrodner@gmail.com",
    description="Reminds you to take breaks",
    long_description_content_type="text/markdown",
    long_description=long_description,
    url="https://github.com/paulbrodner/take-a-break",
    project_urls={
        'Source': 'https://github.com/paulbrodner/take-a-break',
        'Tracker': 'https://github.com/paulbrodner/take-a-break/issues',
    },
    packages=setuptools.find_packages(),
    package_data={'take_a_break': files},
    install_requires=[
        'requests',
        'Pillow'
    ],
    classifiers=[
        "Development Status :: 1 - Planning",
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: GNU General Public License v3 (GPLv3)",
        "Topic :: Utilities",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.8',
)



import logging
import os
import shutil
from configparser import ConfigParser
from os.path import expanduser

from take_a_break import get_resources

INI_FILE = ".take_a_break.ini"


def user_home():
    """
    :return: the path of the current user home
    """
    return expanduser("~")


def config_path():
    return os.path.join(user_home(), INI_FILE)


class Configuration(object):

    def __init__(self):
        if not os.path.exists(config_path()):
            logging.debug("Initialize: {} file".format(config_path()))
            shutil.copy(get_resources(INI_FILE), config_path())

        logging.debug("Reading: {} file".format(config_path()))
        self._data = ConfigParser()
        self._data.read(config_path())

    def load_resources_from_internet(self):
        return bool(self.data["default"]["load_resources_from_internet"].lower() == "true")

    def remind_me_after_this_period(self):
        return int(self.data["default"]["remind_me_after_these_minutes"]) * 60

    @property
    def data(self):
        return self._data

    def save(self):
        with open(config_path(), 'w') as configfile:
            self.data.write(configfile)


CONFIG = Configuration()
